Node

Struct Node 

pub struct Node<BackendT, ContextT, ErrorT, IdT, DataT> {
    pub depth: usize,
    pub kind: NodeKind,
    pub id: IdT,
    pub representation: Representation,
    pub representation_size: XY<usize>,
    pub branch_state: BranchState,
    pub children: Option<NodeList<BackendT, ContextT, ErrorT, IdT, DataT>>,
    pub data: Option<DataT>,
    /* private fields */
}
Tree node.

Fields

depth: usize

Depth.

kind: NodeKind

Kind.

id: IdT

ID.

representation: Representation

Representation.

representation_size: XY<usize>

Representation size.

Cached so we only have to calculate it once.

branch_state: BranchState

State for Branch node.

children: Option<NodeList<BackendT, ContextT, ErrorT, IdT, DataT>>

Children for Branch node.

data: Option<DataT>

Data.

Implementations

Source

impl<BackendT, ContextT, ErrorT, IdT, DataT> Node<BackendT, ContextT, ErrorT, IdT, DataT>
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

pub fn new( depth: usize, kind: NodeKind, id: IdT, representation: Representation, ) -> Self

Constructor.

pub fn symbol(&self, context: ContextT) -> Symbol<'_>

Symbol.

Its char count is always 1.

pub fn at_path(&self, path: NodePath) -> Option<&Self>

Get node at path.

pub fn at_path_mut(&mut self, path: NodePath) -> Option<&mut Self>

Get node at path.

pub fn fill_path(&self, path: &mut NodePath, node: &Self) -> bool

Fill path to node.

Returns true if found.

pub fn populate( &mut self, depth: Option<usize>, context: ContextT, ) -> Result<(), ErrorT>
where ContextT: Clone,

Fetch nodes from backend.

If depth is None will populate all depths.

If depth is 0 will do nothing.

pub fn add_child( &mut self, kind: NodeKind, id: IdT, representation: Representation, )

Add a child node.

pub fn insert_child( &mut self, index: usize, kind: NodeKind, id: IdT, representation: Representation, )

Inserts a child node.

pub fn expand_branch(&mut self, context: ContextT) -> Result<bool, ErrorT>
where ContextT: Clone,

Expand the branch.

Will return false if not a Branch or already expanded.

pub fn collapse_branch(&mut self) -> bool

Collapse the branch.

Will return false if not a Branch or already collapsed.

pub fn toggle_branch_state(&mut self, context: ContextT) -> Result<(), ErrorT>
where ContextT: Clone,

Toggle the branch state.

Expand if collapsed, collapse if expanded.

Will do nothing if not a Branch.

pub fn data( &mut self, context: ContextT, ) -> Result<Option<Cow<'_, DataT>>, ErrorT>
where DataT: Clone,

Data.

If not already cached will fetch it from the backend.