pub struct NodeList<BackendT, ContextT, ErrorT, IdT, DataT>(pub Vec<Node<BackendT, ContextT, ErrorT, IdT, DataT>>);Expand description
Tree node list.
Tuple Fields
0: Vec<Node<BackendT, ContextT, ErrorT, IdT, DataT>>Implementations
Sourceimpl<BackendT, ContextT, ErrorT, IdT, DataT> NodeList<BackendT, ContextT, ErrorT, IdT, DataT>
impl<BackendT, ContextT, ErrorT, IdT, DataT> NodeList<BackendT, ContextT, ErrorT, IdT, DataT>
Sourcepub fn iter(
&self,
only_expanded: bool,
) -> NodeIterator<'_, BackendT, ContextT, ErrorT, IdT, DataT> ⓘ
pub fn iter( &self, only_expanded: bool, ) -> NodeIterator<'_, BackendT, ContextT, ErrorT, IdT, DataT> ⓘ
Iterate nodes in visual order from top to bottom.
When only_expanded is true will skip the children of collapsed branches.
Sourcepub fn at_path(
&self,
path: NodePath,
) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
pub fn at_path(
&self,
path: NodePath,
) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
Get node at path.
Sourcepub fn at_path_mut(
&mut self,
path: NodePath,
) -> Option<&mut Node<BackendT, ContextT, ErrorT, IdT, DataT>>where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
pub fn at_path_mut(
&mut self,
path: NodePath,
) -> Option<&mut Node<BackendT, ContextT, ErrorT, IdT, DataT>>where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
Get node at path.
Sourcepub fn fill_path(
&self,
path: &mut NodePath,
node: &Node<BackendT, ContextT, ErrorT, IdT, DataT>,
) -> boolwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
pub fn fill_path(
&self,
path: &mut NodePath,
node: &Node<BackendT, ContextT, ErrorT, IdT, DataT>,
) -> boolwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
Fill path to node.
Returns true if found.
Sourcepub fn add(
&mut self,
depth: usize,
kind: NodeKind,
id: IdT,
representation: Representation,
)where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
pub fn add(
&mut self,
depth: usize,
kind: NodeKind,
id: IdT,
representation: Representation,
)where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
Add a node.
Sourcepub fn insert(
&mut self,
index: usize,
depth: usize,
kind: NodeKind,
id: IdT,
representation: Representation,
)where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
pub fn insert(
&mut self,
index: usize,
depth: usize,
kind: NodeKind,
id: IdT,
representation: Representation,
)where
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
Insert a node.