TreeModel

Struct TreeModel 

pub struct TreeModel<BackendT>
where BackendT: TreeBackend,
{ pub roots: NodeList<BackendT>, pub context: BackendT::Context, }
Tree model.

Fields

roots: NodeList<BackendT>

Roots.

context: BackendT::Context

Context.

Implementations

Source

impl<BackendT> TreeModel<BackendT>
where BackendT: TreeBackend,

pub fn new(context: BackendT::Context) -> Self

Constructor.

pub fn is_empty(&self) -> bool

Whether we have no nodes.

pub fn iter(&self, only_expanded: bool) -> NodeIterator<'_, BackendT>

Iterate nodes in visual order from top to bottom.

When only_expanded is true will skip the children of collapsed branches.

pub fn at_path(&self, path: NodePath) -> Option<&Node<BackendT>>

Get node at path.

pub fn at_path_mut(&mut self, path: NodePath) -> Option<&mut Node<BackendT>>

Get node at path.

Examples found in repository?
examples/simple.rs (line 20)
8fn main() {
9    let mut cursive = default();
10
11    let mut tree = SimpleTreeBackend::tree_view(());
12
13    // A few roots
14
15    tree.model.add_root(NodeKind::Leaf, (), "Hello".into());
16    tree.model.add_root(NodeKind::Branch, (), "World".into());
17
18    // Add 10 children to "World"
19
20    let world = tree.model.at_path_mut([1].into()).unwrap();
21    for i in 0..10 {
22        world.add_child(NodeKind::Leaf, (), format!("Child #{}", i + 1).into());
23    }
24
25    // Add 10 grandchildren each to "Child #5" -> "Child #10"
26    // Note that we change them to branch in order to support having children
27
28    let mut gc = 0;
29    for c in 4..10 {
30        let child = tree.model.at_path_mut([1, c].into()).unwrap();
31        child.kind = NodeKind::Branch;
32        for _ in 0..10 {
33            child.add_child(NodeKind::Leaf, (), format!("Grandchild #{}", gc + 1).into());
34            gc += 1;
35        }
36    }
37
38    // Expand all nodes
39
40    tree.model.expand(None).unwrap();
41
42    cursive.add_fullscreen_layer(Panel::new(tree.scrollable()));
43    cursive.add_global_callback('q', |cursive| cursive.quit());
44
45    cursive.run();
46}
pub fn at_row(&self, row: usize) -> Option<&Node<BackendT>>

Get node at row.

pub fn path(&self, node: &Node<BackendT>) -> Option<NodePath>

Find path to node.

pub fn extents(&self) -> Vec2

Full extents for drawing.

pub fn add_root( &mut self, kind: NodeKind, id: BackendT::ID, representation: Representation, )

Add a root node.

Examples found in repository?
examples/simple.rs (line 15)
8fn main() {
9    let mut cursive = default();
10
11    let mut tree = SimpleTreeBackend::tree_view(());
12
13    // A few roots
14
15    tree.model.add_root(NodeKind::Leaf, (), "Hello".into());
16    tree.model.add_root(NodeKind::Branch, (), "World".into());
17
18    // Add 10 children to "World"
19
20    let world = tree.model.at_path_mut([1].into()).unwrap();
21    for i in 0..10 {
22        world.add_child(NodeKind::Leaf, (), format!("Child #{}", i + 1).into());
23    }
24
25    // Add 10 grandchildren each to "Child #5" -> "Child #10"
26    // Note that we change them to branch in order to support having children
27
28    let mut gc = 0;
29    for c in 4..10 {
30        let child = tree.model.at_path_mut([1, c].into()).unwrap();
31        child.kind = NodeKind::Branch;
32        for _ in 0..10 {
33            child.add_child(NodeKind::Leaf, (), format!("Grandchild #{}", gc + 1).into());
34            gc += 1;
35        }
36    }
37
38    // Expand all nodes
39
40    tree.model.expand(None).unwrap();
41
42    cursive.add_fullscreen_layer(Panel::new(tree.scrollable()));
43    cursive.add_global_callback('q', |cursive| cursive.quit());
44
45    cursive.run();
46}
pub fn insert_root( &mut self, index: usize, kind: NodeKind, id: BackendT::ID, representation: Representation, )

Insert a root node.

pub fn expand(&mut self, depth: Option<usize>) -> Result<(), BackendT::Error>
where BackendT::Context: Clone,

Expand branch nodes.

If depth is None will expand the entire tree.

If depth is 0 will do nothing.

Note that this will populate expanded nodes from the backend.

Examples found in repository?
examples/simple.rs (line 40)
8fn main() {
9    let mut cursive = default();
10
11    let mut tree = SimpleTreeBackend::tree_view(());
12
13    // A few roots
14
15    tree.model.add_root(NodeKind::Leaf, (), "Hello".into());
16    tree.model.add_root(NodeKind::Branch, (), "World".into());
17
18    // Add 10 children to "World"
19
20    let world = tree.model.at_path_mut([1].into()).unwrap();
21    for i in 0..10 {
22        world.add_child(NodeKind::Leaf, (), format!("Child #{}", i + 1).into());
23    }
24
25    // Add 10 grandchildren each to "Child #5" -> "Child #10"
26    // Note that we change them to branch in order to support having children
27
28    let mut gc = 0;
29    for c in 4..10 {
30        let child = tree.model.at_path_mut([1, c].into()).unwrap();
31        child.kind = NodeKind::Branch;
32        for _ in 0..10 {
33            child.add_child(NodeKind::Leaf, (), format!("Grandchild #{}", gc + 1).into());
34            gc += 1;
35        }
36    }
37
38    // Expand all nodes
39
40    tree.model.expand(None).unwrap();
41
42    cursive.add_fullscreen_layer(Panel::new(tree.scrollable()));
43    cursive.add_global_callback('q', |cursive| cursive.quit());
44
45    cursive.run();
46}
pub fn collapse(&mut self, depth: Option<usize>)

Collapse branch nodes.

If depth is None will collapse the entire tree.

If depth is 0 will do nothing.

pub fn populate(&mut self, depth: Option<usize>) -> Result<(), BackendT::Error>
where BackendT::Context: Clone,

Fetch roots and possibly their children from backend.

If depth is None will populate the entire tree.

If depth is 1 will only populate the roots.

If depth is 0 will do nothing.

Note that populating a branch node will not automatically expand it.

Examples found in repository?
examples/file_browser.rs (line 20)
13fn main() {
14    let mut cursive = default();
15
16    let current_dir = current_dir().unwrap();
17    let mut tree = FileBackend::tree_view(current_dir.into());
18
19    // Populate the first level (just the roots)
20    tree.model.populate(Some(1)).unwrap();
21
22    let mut browser = LinearLayout::horizontal();
23    browser.add_child(Panel::new(tree.with_name("tree").scrollable()));
24    browser.add_child(Panel::new(TextView::new("").with_name("details").scrollable()));
25
26    cursive.add_fullscreen_layer(browser);
27    cursive.add_global_callback('q', |cursive| cursive.quit());
28
29    cursive.run();
30}
pub fn clear(&mut self)

Remove all nodes.