TreeModel

Struct TreeModel 

pub struct TreeModel<BackendT, ContextT, ErrorT, IdT, DataT> {
    pub roots: NodeList<BackendT, ContextT, ErrorT, IdT, DataT>,
    pub context: ContextT,
    /* private fields */
}
Tree model.

Fields

roots: NodeList<BackendT, ContextT, ErrorT, IdT, DataT>

Roots.

context: ContextT

Context.

Implementations

Source

impl<BackendT, ContextT, ErrorT, IdT, DataT> TreeModel<BackendT, ContextT, ErrorT, IdT, DataT>

pub fn new(context: ContextT) -> Self

Constructor.

pub fn is_empty(&self) -> bool

Whether we have no nodes.

pub fn iter( &self, only_expanded: bool, ) -> NodeIterator<'_, BackendT, ContextT, ErrorT, IdT, DataT>

Iterate nodes in visual order from top to bottom.

When only_expanded is true will skip the children of collapsed branches.

pub fn at_path( &self, path: NodePath, ) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

Get node at path.

pub fn at_path_mut( &mut self, path: NodePath, ) -> Option<&mut Node<BackendT, ContextT, ErrorT, IdT, DataT>>
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

Get node at path.

pub fn at_row( &self, row: usize, ) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>
where DataT: 'static,

Get node at row.

pub fn path( &self, node: &Node<BackendT, ContextT, ErrorT, IdT, DataT>, ) -> Option<NodePath>
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

Find path to node.

pub fn size(&self) -> XY<usize>
where DataT: 'static,

Size.

pub fn add_root( &mut self, kind: NodeKind, id: IdT, representation: Representation, )
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

Add a root node.

pub fn insert_root( &mut self, index: usize, kind: NodeKind, id: IdT, representation: Representation, )
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,

Insert a root node.

pub fn populate(&mut self, depth: Option<usize>) -> Result<(), ErrorT>
where BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>, ContextT: Clone,

Fetch nodes from backend.

If depth is None will populate the entire tree.

If depth is 0 will do nothing.

pub fn clear(&mut self)

Remove all nodes.