TreeView

Struct TreeView 

pub struct TreeView<BackendT>
where BackendT: TreeBackend,
{ pub model: TreeModel<BackendT>, pub selected_row: Option<usize>, pub page: usize, pub debug: bool, }
Tree view.

Nodes can be leaves (no children) or branches (potentially have children) and can have custom data (DataT) attached to them. Their representation can be stylized with multiple colors and effects.

Supported events:

  • Up/Down keys: move selection
  • PgUp/PgDown keys: move selection by 10 (configurable)
  • Left/Right keys: collapse/expand selected branch node
  • Enter key: toggle selected branch node collapse/expand
  • “-”/“+” keys: collapse/expand selected branch and all children recursively
  • Mouse click on node: select
  • Mouse click to the left of the node: toggle branch collapse/expand

The view’s data and behavior are backed by a TreeBackend. The nodes are stored and managed by a TreeModel. The model can be populated in advance and can also fetch data from the backend on demand, e.g. when a branch node is expanded.

Fields

model: TreeModel<BackendT>

Tree model.

selected_row: Option<usize>

Selected row.

page: usize

Page size for PgUp/PgDown.

debug: bool

Whether we want to display debug information.

Implementations

Source

impl<BackendT> TreeView<BackendT>
where BackendT: TreeBackend,

pub fn selected_node(&self) -> Option<&Node<BackendT>>

The selected node.

pub fn selected_path(&self) -> Option<NodePath>

The selected path.

pub fn selected_node_mut(&mut self) -> Option<&mut Node<BackendT>>

The selected node.

Examples found in repository?
examples/file_browser.rs (line 67)
63    fn handle_selection_changed(cursive: &mut Cursive) {
64        let content = match cursive.call_on_name("tree", |tree: &mut TreeView<Self>| {
65            // Although we're not using the context in data() but we still need to provide it
66            let base_directory = tree.model.context.clone();
67            Ok(match tree.selected_node_mut() {
68                Some(node) => match node.data(base_directory)? {
69                    Some(metadata) => Some(format_metadata(&metadata)?),
70                    None => None,
71                },
72                None => None,
73            })
74        }) {
75            Some(Ok(Some(text))) => text,
76            Some(Err(error)) => return Self::handle_error(cursive, error),
77            _ => "".into(),
78        };
79
80        cursive.call_on_name("details", |details: &mut TextView| {
81            details.set_content(content);
82        });
83    }
pub fn is_selected(&self, row: usize) -> bool

Whether the row is selected.

pub fn select_top(&mut self)

Select top row.

pub fn select_bottom(&mut self)

Select bottom row.

pub fn move_selection(&mut self, delta: isize)

Move selection by delta rows.