pub struct TreeView<BackendT, ContextT, ErrorT, IdT, DataT> {
pub model: TreeModel<BackendT, ContextT, ErrorT, IdT, DataT>,
pub selected_row: Option<usize>,
pub page: usize,
pub debug: bool,
}Expand description
Tree view.
Nodes can be leaves (no children) or branches (potentially have children) and can have custom
data (DataT) attached to them. Their representation can be stylized with multiple colors and
effects.
Supported events:
- Up/Down keys: move selection
- PgUp/PgDown keys: move selection by 10 (configurable)
- Left/Right keys: collapse/expand branch node
- Enter key: toggle branch collapse/expand
- Mouse click on node: select
- Mouse click to the left of the node: toggle branch collapse/expand
The view’s data and behavior are backed by a TreeBackend. The nodes are stored and managed by a TreeModel. The model can be populated in advance and can also fetch data from the backend on demand, e.g. when a branch node is expanded.
Fields
model: TreeModel<BackendT, ContextT, ErrorT, IdT, DataT>Tree model.
selected_row: Option<usize>Selected row.
page: usizePage size for PgUp/PgDown.
debug: boolWhether we want to display debug information.
Implementations
Sourceimpl<BackendT, ContextT, ErrorT, IdT, DataT> TreeView<BackendT, ContextT, ErrorT, IdT, DataT>where
BackendT: 'static + TreeBackend<ContextT, ErrorT, IdT, DataT> + Send + Sync,
DataT: 'static + Send + Sync,
impl<BackendT, ContextT, ErrorT, IdT, DataT> TreeView<BackendT, ContextT, ErrorT, IdT, DataT>where
BackendT: 'static + TreeBackend<ContextT, ErrorT, IdT, DataT> + Send + Sync,
DataT: 'static + Send + Sync,
Sourcepub fn selected_node(
&self,
) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>
pub fn selected_node( &self, ) -> Option<&Node<BackendT, ContextT, ErrorT, IdT, DataT>>
The selected node.
Sourcepub fn selected_path(&self) -> Option<NodePath>
pub fn selected_path(&self) -> Option<NodePath>
The selected path.
Sourcepub fn selected_node_mut(
&mut self,
) -> Option<&mut Node<BackendT, ContextT, ErrorT, IdT, DataT>>
pub fn selected_node_mut( &mut self, ) -> Option<&mut Node<BackendT, ContextT, ErrorT, IdT, DataT>>
The selected node.
Sourcepub fn is_selected(&self, row: usize) -> bool
pub fn is_selected(&self, row: usize) -> bool
Whether the row is selected.
Sourcepub fn select_top(&mut self)
pub fn select_top(&mut self)
Select top row.
Sourcepub fn select_bottom(&mut self)
pub fn select_bottom(&mut self)
Select bottom row.
Sourcepub fn move_selection(&mut self, delta: isize)
pub fn move_selection(&mut self, delta: isize)
Move selection by delta rows.
Sourceimpl<BackendT, ContextT, ErrorT, IdT, DataT> TreeView<BackendT, ContextT, ErrorT, IdT, DataT>
impl<BackendT, ContextT, ErrorT, IdT, DataT> TreeView<BackendT, ContextT, ErrorT, IdT, DataT>
Sourcepub fn toggle_branch_state(
node: &mut Node<BackendT, ContextT, ErrorT, IdT, DataT>,
context: ContextT,
) -> EventResultwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
ContextT: Clone,
ErrorT: 'static + Send + Sync,
pub fn toggle_branch_state(
node: &mut Node<BackendT, ContextT, ErrorT, IdT, DataT>,
context: ContextT,
) -> EventResultwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
ContextT: Clone,
ErrorT: 'static + Send + Sync,
Toggle branch state.
Sourcepub fn expand_branch(
node: &mut Node<BackendT, ContextT, ErrorT, IdT, DataT>,
context: ContextT,
) -> EventResultwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
ContextT: Clone,
ErrorT: 'static + Send + Sync,
pub fn expand_branch(
node: &mut Node<BackendT, ContextT, ErrorT, IdT, DataT>,
context: ContextT,
) -> EventResultwhere
BackendT: TreeBackend<ContextT, ErrorT, IdT, DataT>,
ContextT: Clone,
ErrorT: 'static + Send + Sync,
Expand branch.